@@ -1,6 +1,7 @@
-from typing import Callable, Optional
-import weakref
-from pydantic import BaseModel as PydanticBaseModel, PrivateAttr
+from pydantic import BaseModel as PydanticBaseModel
+
+from pydantic.class_validators import root_validator
+from .utils import make_hashable
 
 
 class BaseModel(PydanticBaseModel):
@@ -23,3 +24,9 @@ class BaseModel(PydanticBaseModel):
         raise NotImplementedError(
             f"Model {self.__class__.__name__} has no update method"
         )
+
+    # After running validation on all known properties, make sure everything else is hashable
+    @root_validator(allow_reuse=True, pre=False)
+    def make_hashable_root(cls, values):
+        # The root validator must take and return a dict
+        return {k: make_hashable(v) for k, v in values.items()}
