@@ -103,7 +103,8 @@ class OperationEnrichResults(BaseOperation):
 
 
 class FillAllowParameters(BaseModel):
-    allowlist: HashableSequence[str]
+    allowlist: Optional[HashableSequence[str]]
+    qedge_keys: Optional[HashableSequence[str]]
     _nonzero_allowlist = validator("allowlist", allow_reuse=True)(nonzero_validator)
 
     class Config:
@@ -111,7 +112,8 @@ class FillAllowParameters(BaseModel):
 
 
 class FillDenyParameters(BaseModel):
-    denylist: HashableSequence[str]
+    denylist: Optional[HashableSequence[str]]
+    qedge_keys: Optional[HashableSequence[str]]
     _nonzero_denylist = validator("denylist", allow_reuse=True)(nonzero_validator)
 
     class Config:
